# pvml
## A simple Machine Learning library 

The library include code for many classic machine learning models such as logistic regression, svm, neural networks etc.

The code is particularly aimed to students in machine learning and does not require advanced programming skills, just a basic understanding of Python and the numpy package.

**Do not expect** optimized algorithms or a sophisticated design.

If your objective is to obtain good results quickly, please consider using a more professional library such as [scikit-learn](https://scikit-learn.org).

# Installation

The library is available on [PYPI](https://pypi.org/project/pvml/) and can be installed as follows

```pip3 install pvml```
